# Aan de slag!

Welkom bij Rapunzel, een moderne ontwikkelomgeving voor Python en R. Hier zijn enkele handige sneltoetsen.


## Werken met projectmappen en bestanden

- [`Ctrl+Shift+O`: Open projectmap](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`: Open bestand uit projectmappen](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`: Maak leeg document](opensesame://event.ide_new_file)


## Dingen snel doen

- [`Ctrl+Shift+P`: Activeer commando-palet](opensesame://event.command_palette_activate)
- `Ctrl+R`: Ga naar functie of klasse


## Code uitvoeren

- `F5`: Voer project of bestand uit
- `F9`: Voer selectie, cel of huidige regel uit